pub struct IncompleteUtf8 {
pub buffer: [u8; 4],
pub buffer_len: u8,
}Fields
buffer: [u8; 4]buffer_len: u8Implementations
Sourceimpl IncompleteUtf8
impl IncompleteUtf8
Sourcepub fn try_to_complete_codepoint<'input>(
&mut self,
input: &'input [u8],
) -> Option<(Result<&str, &[u8]>, &'input [u8])>
pub fn try_to_complete_codepoint<'input>( &mut self, input: &'input [u8], ) -> Option<(Result<&str, &[u8]>, &'input [u8])>
Attempts to complete the codepoint given the bytes from input.
Returns None if more input is required to complete the codepoint. In this case, no
input is consumed.
Otherwise, returns either the decoded &str or malformed &[u8] and the remaining input.
pub fn try_complete<A, F>( &mut self, input: Tendril<Bytes, A>, push_utf8: F, ) -> Result<Tendril<Bytes, A>, ()>